# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc_py_gen/dependency.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'grpc_py_gen/dependency.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgrpc_py_gen/dependency.proto\x12\ndependency\"8\n\nDependency\x12\x0c\n\x04word\x18\x01 \x01(\t\x12\x0f\n\x07gov_idx\x18\x02 \x01(\x05\x12\x0b\n\x03rel\x18\x03 \x01(\t\">\n\x0e\x44\x65pendencyList\x12,\n\x0c\x64\x65pendencies\x18\x01 \x03(\x0b\x32\x16.dependency.Dependency\"6\n\x18ParseDependenciesRequest\x12\x0c\n\x04lang\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"P\n\x19ParseDependenciesResponse\x12\x33\n\x0f\x64\x65pendency_list\x18\x01 \x03(\x0b\x32\x1a.dependency.DependencyList2u\n\x11\x44\x65pendencyService\x12`\n\x11ParseDependencies\x12$.dependency.ParseDependenciesRequest\x1a%.dependency.ParseDependenciesResponseB-Z+github.com/citadel2024/word_segment_grpc_gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_py_gen.dependency_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/citadel2024/word_segment_grpc_go'
  _globals['_DEPENDENCY']._serialized_start=44
  _globals['_DEPENDENCY']._serialized_end=100
  _globals['_DEPENDENCYLIST']._serialized_start=102
  _globals['_DEPENDENCYLIST']._serialized_end=164
  _globals['_PARSEDEPENDENCIESREQUEST']._serialized_start=166
  _globals['_PARSEDEPENDENCIESREQUEST']._serialized_end=220
  _globals['_PARSEDEPENDENCIESRESPONSE']._serialized_start=222
  _globals['_PARSEDEPENDENCIESRESPONSE']._serialized_end=302
  _globals['_DEPENDENCYSERVICE']._serialized_start=304
  _globals['_DEPENDENCYSERVICE']._serialized_end=421
# @@protoc_insertion_point(module_scope)
