# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc_py_gen/segment.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'grpc_py_gen/segment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19grpc_py_gen/segment.proto\x12\x11word_segmentation\"\x1f\n\x0eSegmentRequest\x12\r\n\x05input\x18\x01 \x01(\t\"!\n\x0fSegmentResponse\x12\x0e\n\x06output\x18\x01 \x03(\t2d\n\x10WordSegmentation\x12P\n\x07Segment\x12!.word_segmentation.SegmentRequest\x1a\".word_segmentation.SegmentResponseB-Z+github.com/citadel2024/word_segment_grpc_gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_py_gen.segment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/citadel2024/word_segment_grpc_go'
  _globals['_SEGMENTREQUEST']._serialized_start=48
  _globals['_SEGMENTREQUEST']._serialized_end=79
  _globals['_SEGMENTRESPONSE']._serialized_start=81
  _globals['_SEGMENTRESPONSE']._serialized_end=114
  _globals['_WORDSEGMENTATION']._serialized_start=116
  _globals['_WORDSEGMENTATION']._serialized_end=216
# @@protoc_insertion_point(module_scope)
