# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc_py_gen/ner.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'grpc_py_gen/ner.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15grpc_py_gen/ner.proto\x12\x03ner\"N\n\x06\x45ntity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0c\n\x04prob\x18\x04 \x01(\x02\x12\x0c\n\x04span\x18\x05 \x01(\t\"+\n\nEntityList\x12\x1d\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x0b.ner.Entity\"\x1a\n\nNerRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\"3\n\x0bNerResponse\x12$\n\x0b\x65ntity_list\x18\x01 \x01(\x0b\x32\x0f.ner.EntityList2B\n\nNerService\x12\x34\n\x0f\x45xtractEntities\x12\x0f.ner.NerRequest\x1a\x10.ner.NerResponseB-Z+github.com/citadel2024/word_segment_grpc_gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_py_gen.ner_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/citadel2024/word_segment_grpc_go'
  _globals['_ENTITY']._serialized_start=30
  _globals['_ENTITY']._serialized_end=108
  _globals['_ENTITYLIST']._serialized_start=110
  _globals['_ENTITYLIST']._serialized_end=153
  _globals['_NERREQUEST']._serialized_start=155
  _globals['_NERREQUEST']._serialized_end=181
  _globals['_NERRESPONSE']._serialized_start=183
  _globals['_NERRESPONSE']._serialized_end=234
  _globals['_NERSERVICE']._serialized_start=236
  _globals['_NERSERVICE']._serialized_end=302
# @@protoc_insertion_point(module_scope)
